summaryrefslogtreecommitdiffstats
path: root/wp-includes/vars.php
diff options
context:
space:
mode:
Diffstat (limited to 'wp-includes/vars.php')
-rw-r--r--wp-includes/vars.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/wp-includes/vars.php b/wp-includes/vars.php
index a123696..b719b48 100644
--- a/wp-includes/vars.php
+++ b/wp-includes/vars.php
@@ -10,7 +10,7 @@
* servers with known pretty permalink capability.
*
* Note: Though Nginx is detected, WordPress does not currently
- * generate rewrite rules for it. See https://wordpress.org/documentation/article/nginx/
+ * generate rewrite rules for it. See https://developer.wordpress.org/advanced-administration/server/web-server/nginx/
*
* @package WordPress
*/
@@ -127,11 +127,11 @@ $is_apache = ( str_contains( $_SERVER['SERVER_SOFTWARE'], 'Apache' ) || str_cont
$is_nginx = ( str_contains( $_SERVER['SERVER_SOFTWARE'], 'nginx' ) );
/**
* Whether the server software is Caddy or something else.
*
* @global bool $is_caddy
*/
-$is_caddy = ( str_contains( $_SERVER['SERVER_SOFTWARE'], 'Caddy' ) );
+$is_caddy = ( str_contains( $_SERVER['SERVER_SOFTWARE'], 'Caddy' ) || str_contains( $_SERVER['SERVER_SOFTWARE'], 'FrankenPHP' ) );
/**
* Whether the server software is IIS or something else.
@@ -127,11 +127,11 @@ $is_apache = ( str_contains( $_SERVER['SERVER_SOFTWARE'], 'Apache' ) || str_cont
$is_nginx = ( str_contains( $_SERVER['SERVER_SOFTWARE'], 'nginx' ) );
/**
- * Whether the server software is Caddy or something else.
+ * Whether the server software is Caddy / FrankenPHP or something else.
*
* @global bool $is_caddy